@@ -5,7 +5,7 @@
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
 ;; URL: https://github.com/protesilaos/consult-denote
-;; Version: 0.2.1
+;; Version: 0.2.2
 ;; Package-Requires: ((emacs "28.1") (denote "3.0.3") (consult "1.7"))
 
 ;; This file is NOT part of GNU Emacs.
@@ -147,17 +147,6 @@ Return the absolute path to the matching file."
      :history 'denote-link-find-file-history
      :prompt "Find linked file")))
 
-(defun consult-denote-select-linked-file-prompt (files)
-  "Prompt for Denote file among FILES."
-  (let* ((default-directory denote-directory)
-         (file-names (mapcar #'denote-get-file-name-relative-to-denote-directory files)))
-    (consult--read
-     (denote--completion-table 'file file-names)
-     :prompt "Select FILE: "
-     :require-match t
-     :state (consult--file-preview)
-     :history 'denote-link-find-file-history)))
-
 (defun consult-denote-silo-directory-prompt ()
   "Like the `denote-silo-extras-directory-prompt' with Consult preview."
   (let ((default (car denote-silo-extras-directory-history)))
@@ -180,8 +169,8 @@ FILE has the same meaning as in `denote-org-extras-outline-prompt'."
      (denote--completion-table-no-sort 'imenu (denote-org-extras--get-outline current-file))
      :state (lambda (_action candidate)
               (with-current-buffer (current-buffer)
-                (when-let ((_ candidate)
-                           (line (string-to-number (car (split-string candidate)))))
+                (when-let* ((_ candidate)
+                            (line (string-to-number (car (split-string candidate)))))
                   (goto-line line (get-file-buffer current-file)))))
      :prompt (format "Select heading inside `%s': " (propertize (file-name-nondirectory current-file) 'face 'denote-faces-prompt-current-name))
      :require-match t)))
@@ -223,9 +212,9 @@ FILE has the same meaning as in `denote-org-extras-outline-prompt'."
   (delq nil
         (mapcar
          (lambda (buffer)
-           (when-let ((file (buffer-file-name buffer))
-                      ((buffer-live-p buffer))
-                      ((denote-filename-is-note-p file)))
+           (when-let* ((file (buffer-file-name buffer))
+                       ((buffer-live-p buffer))
+                       ((denote-filename-is-note-p file)))
              (buffer-name buffer)))
          (buffer-list))))
 
@@ -292,5 +281,29 @@ FILE has the same meaning as in `denote-org-extras-outline-prompt'."
     (advice-remove #'denote-org-extras-outline-prompt #'consult-denote-outline-prompt)
     (advice-remove #'denote-silo-extras-directory-prompt #'consult-denote-silo-directory-prompt)))
 
+;;;; Alternatives to Denote functions
+
+(defun consult-denote--subdirectory-p (directory)
+  "Return non-nil if DIRECTORY is a subdirectory of variable `denote-directory'."
+  (member directory (denote-directory-subdirectories)))
+
+(defun consult-denote--get-subdir-or-root ()
+  "Return current subdirectory of the variable `denote-directory'.
+If that is not available, return the value of variable
+`denote-directory'."
+  (if-let* ((current-dir (expand-file-name default-directory))
+            ((consult-denote--subdirectory-p current-dir)))
+      current-dir
+    (denote-directory)))
+
+(defun consult-denote--get-file-with-find (&optional directory)
+  "Use Consult to find a file in the variable `denote-directory'.
+With optional DIRECTORY, search that directory instead."
+  (let ((dir (or directory (consult-denote--get-subdir-or-root))))
+    (pcase-let* ((`(,prompt ,paths ,dir) (consult--directory-prompt "Find" dir))
+                 (default-directory dir)
+                 (builder (consult--find-make-builder paths)))
+      (consult--find prompt builder nil))))
+
 (provide 'consult-denote)
 ;;; consult-denote.el ends here
